@@ -1,12 +1,11 @@
 package Date::WeekNumber;
 # ABSTRACT: calculate week of the year (ISO 8601 weeks, or 'CPAN weeks')
-$Date::WeekNumber::VERSION = '0.01';
+$Date::WeekNumber::VERSION = '0.02';
 use 5.006;
 use strict;
 use warnings;
 use parent 'Exporter';
 use Carp;
-use POSIX qw(strftime);
 use Scalar::Util qw/ reftype /;
 
 our @EXPORT_OK = qw(iso_week_number cpan_week_number);
@@ -14,8 +13,12 @@ our @EXPORT_OK = qw(iso_week_number cpan_week_number);
 sub iso_week_number
 {
     my $date = _dwim_date(@_);
-    return strftime('%G-W%V', 0, 0, 12,
-                    $date->{day}, $date->{month}-1, $date->{year}-1900);
+
+    require Date::Calc;
+
+    my ($week, $year) = Date::Calc::Week_of_Year($date->{year}, $date->{month}, $date->{day});
+
+    return sprintf('%.4d-W%.2d', $year, $week);
 }
 
 # If %U returns a week number of 0, it means the day
@@ -24,13 +27,15 @@ sub iso_week_number
 sub cpan_week_number
 {
     my $date = _dwim_date(@_);
-    my $week_number = strftime('%U', 0, 0, 12,
+
+    require POSIX;
+    my $week_number = POSIX::strftime('%U', 0, 0, 12,
                                $date->{day},
                                $date->{month}-1,
                                $date->{year}-1900);
     if ($week_number == 0) {
         $date->{year}--;
-        $week_number = strftime('%U', 0, 0, 12, 31, 11, $date->{year}-1900);
+        $week_number = POSIX::strftime('%U', 0, 0, 12, 31, 11, $date->{year}-1900);
     }
     return sprintf('%.4d-W%.2d', $date->{year}, $week_number);
 }
@@ -192,6 +197,13 @@ It also provides C<strftime()>.
 L<Date::Calc> provides C<Week_of_Year()>, which returns
 the ISO week number and associated year.
 
+L<Date::ISO8601> provides a number of functions for converting
+dates according to ISO 8601.
+
+L<Date::ISO> can be used to produce an ISO week number,
+but you need to use the C<iso_year()> method, which isn't
+mentioned in the documentation.
+
 L<Date::WeekOfYear> provides a C<WeekOfYear()> function,
 which returns the week number and associated year.
 It doesn't say what scheme it follows though, and it
